@@ -36,7 +36,7 @@ class Helper : public QObject
 
 public:
     //* constructor
-    explicit Helper(KSharedConfig::Ptr, QObject *parent = nullptr);
+    explicit Helper(KSharedConfig::Ptr);
 
     //* destructor
     virtual ~Helper()
@@ -210,6 +210,8 @@ public:
                          bool roundCorners = true,
                          Qt::Edges seamlessEdges = Qt::Edges()) const;
 
+    QRegion menuFrameRegion(const QMenu *widget);
+
     //* button frame
     void renderButtonFrame(QPainter *painter,
                            const QRectF &rect,
@@ -307,6 +309,12 @@ public:
     //* tabbar tab
     void renderTabBarTab(QPainter *, const QRectF &, const QPalette &palette, const QHash<QByteArray, bool> &stateProperties, Corners corners, qreal animation)
         const;
+    void renderStaticTabBarTab(QPainter *,
+                               const QRectF &,
+                               const QPalette &palette,
+                               const QHash<QByteArray, bool> &stateProperties,
+                               Corners corners,
+                               qreal animation) const;
     // TODO(janet): document should be set based on whether or not we consider the
     // tab user-editable, but Qt apps often misuse or don't use documentMode property
     // so we're currently just always setting it to true for now
@@ -319,7 +327,7 @@ public:
     void renderDecorationButton(QPainter *, const QRectF &, const QColor &, ButtonType, bool inverted) const;
 
     //* generic shadow for rounded rectangles
-    void renderRoundedRectShadow(QPainter *, const QRectF &, const QColor &, qreal radius = Metrics::Frame_FrameRadius - PenWidth::Shadow / 2) const;
+    void renderRoundedRectShadow(QPainter *, const QRectF &, const QColor &, qreal radius) const;
 
     //* generic shadow for ellipses
     void renderEllipseShadow(QPainter *, const QRectF &, const QColor &) const;
@@ -428,6 +436,7 @@ protected:
     bool eventFilter(QObject *watched, QEvent *event) override;
 
 private:
-    Helper *_helper;
+    // lifetime: helper IS the parent QObject. When it is destructed, so is the filter.
+    Helper *_helper = nullptr;
 };
 }
